@@ -145,14 +145,26 @@ class SandboxService:
             self.logger.info('Creating Grasp sandbox', {
                 'templateId': template_id,
             })
+
+            domain = 'e2b.app'
+            if api_key.startswith('sk_'):
+                domain = 'sandbox.novita.ai'
+                template_id = f'{template_id}-novita'
+
+            timeoutSec = self.config['timeout'] // 1000
+
             # Use Sandbox constructor directly (e2b SDK 1.5.3+)
             self.sandbox = await AsyncSandbox.create(
                 template=template_id,    
                 api_key=api_key,
-                timeout=self.config['timeout'] // 1000,  # Convert ms to seconds
+                domain=domain,
+                timeout=min(timeoutSec, 3600),  # Convert ms to seconds
                 envs=envs,
             )
 
+            if timeoutSec > 3600:
+                await self.sandbox.set_timeout(timeout=timeoutSec)
+
             self.status = SandboxStatus.RUNNING
             self.logger.info('Grasp sandbox created successfully', {
                 'sandboxId': getattr(self.sandbox, 'sandbox_id', 'unknown'),
